pub enum StatDataSource {
EventDelta(RawEventDeltaSpec),
FieldValue(RawFieldCaptureSpec),
}Expand description
Represents the different ways a line’s data can be sourced from logs in order to display some stats.
Variants
EventDelta(RawEventDeltaSpec)
Extract the time delta between consecutive occurrences of pattern.
FieldValue(RawFieldCaptureSpec)
Extract a numeric field from logs.
This is the most common data source type.