FieldCaptureSpec

Struct FieldCaptureSpec 

pub struct FieldCaptureSpec {
    pub guard: Option<String>,
    pub field: String,
}
Describes how to capture a numeric value from log lines using an optional guard and a field pattern.

This specification is used by the data source to determine how to parse plotted values.

Fields

guard: Option<String>

Optional guard string to quickly filter out log lines using strcmp

field: String

The name of the field to parse as numeric or regex. Refer to “Plot Field Regex” help section for more details.